@@ -150,6 +150,12 @@ DPMGibbsN_parallel <- function (Ncpus, type_connec,
   
   dpmclus <- NULL
   
+  if(!requireNamespace("itertools", quietly=TRUE)){
+    stop("Package 'itertools' is not available.\n  -> Try running 'install.packages(\"itertools\")'\n   or use non parallel version of the function: 'DPMGibbsN'")
+  }else{
+    requireNamespace("itertools", quietly=TRUE)
+  }
+  
   if(!requireNamespace("doParallel", quietly=TRUE)){
     stop("Package 'doParallel' is not available.\n  -> Try running 'install.packages(\"doParallel\")'\n   or use non parallel version of the function: 'DPMGibbsN'")
   }else{
@@ -170,21 +176,8 @@ DPMGibbsN_parallel <- function (Ncpus, type_connec,
     U_B = array(0, dim=c(2, 2, n))
     U_nu <- rep(p,n)
     
-    par_ind <- list()
-    temp_ind <- 0
-    if(Ncpus>1){
-      nb_simult <- floor(n%/%(Ncpus))
-      for(i in 1:(Ncpus-1)){
-        par_ind[[i]] <- temp_ind + 1:nb_simult
-        temp_ind <- temp_ind + nb_simult
-      }
-      par_ind[[Ncpus]] <- (temp_ind+1):n
-    }
-    else{
-      cat("Only 1 core specified\n=> non-parallel version of the algorithm would be more efficient",
-          file=monitorfile, append = TRUE)
-      nb_simult <- n
-      par_ind[[Ncpus]] <- (temp_ind+1):n
+    if(Ncpus<2){
+      warning("Only 1 core specified\n=> non-parallel version of the algorithm would be more efficient")
     }
     
     
@@ -310,8 +303,7 @@ DPMGibbsN_parallel <- function (Ncpus, type_connec,
       )
       slice <- sliceSampler_N_parallel(Ncpus=Ncpus, c=c, m=m, alpha=alpha[i],
                                        z=z, hyperG0=hyperG0,
-                                       U_mu=U_mu, U_Sigma=U_Sigma, diagVar=diagVar,
-                                       parallel_index=par_ind)
+                                       U_mu=U_mu, U_Sigma=U_Sigma, diagVar=diagVar)
       
       m <- slice[["m"]]
       c <- slice[["c"]]
