@@ -179,6 +179,12 @@ DPMGibbsSkewT_SeqPrior_parallel <- function (Ncpus, type_connec,
 
   dpmclus <- NULL
 
+  if(!requireNamespace("itertools", quietly=TRUE)){
+    stop("Package 'itertools' is not available.\n  -> Try running 'install.packages(\"itertools\")'\n   or use non parallel version of the function: 'DPMGibbsN'")
+  }else{
+    requireNamespace("itertools", quietly=TRUE)
+  }
+  
   if(!requireNamespace("doParallel", quietly=TRUE)){
     stop("Package 'doParallel' is not available.\n  -> Try running 'install.packages(\"doParallel\")'\n   or use non parallel version of the function: 'DPMGibbsN'")
   }else{
@@ -200,22 +206,9 @@ DPMGibbsSkewT_SeqPrior_parallel <- function (Ncpus, type_connec,
     U_B <- array(0, dim=c(2, 2, n))
     U_nu <- rep(p,n)
 
-    par_ind <- list()
-    temp_ind <- 0
-    if(Ncpus>1){
-        nb_simult <- floor(n%/%(Ncpus))
-        for(i in 1:(Ncpus-1)){
-            par_ind[[i]] <- temp_ind + 1:nb_simult
-            temp_ind <- temp_ind + nb_simult
-        }
-        par_ind[[Ncpus]] <- (temp_ind+1):n
-    }
-    else{
-        cat("Only 1 core specified\n=> non-parallel version of the algorithm would be more efficient")
-        cat("Only 1 core specified\n=> non-parallel version of the algorithm would be more efficient",
-            file=monitorfile, append = TRUE)
-        nb_simult <- n
-        par_ind[[Ncpus]] <- (temp_ind+1):n
+    
+    if(Ncpus<2){
+      warning("Only 1 core specified\n=> non-parallel version of the algorithm would be more efficient")
     }
 
     # U_SS is a list where each U_SS[[k]] contains the sufficient
@@ -332,8 +325,7 @@ DPMGibbsSkewT_SeqPrior_parallel <- function (Ncpus, type_connec,
                                                           U_psi=U_psi,
                                                           U_Sigma=U_Sigma,
                                                           U_df=U_df,
-                                                          scale=sc, diagVar,
-                                                          parallel_index=par_ind)
+                                                          scale=sc, diagVar)
             m <- slice[["m"]]
             c <- slice[["c"]]
             weights_list[[i]] <- slice[["weights"]]
