@@ -1,4 +1,4 @@
-dNiW <- function(mu, Sigma, hyperprior){
+dNiW <- function(mu, Sigma, hyperprior, log=FALSE){
     
     res=NA
     
@@ -16,12 +16,19 @@ dNiW <- function(mu, Sigma, hyperprior){
         mu <- lapply(mu, FUN='[[', 1)
     }
     
+    if(!log){
     res <- mapply(function(mu, Sigma){
         det(Sigma)^(-(nu0+p+2)/2)*
             exp(-sum(diag(lambda0%*%solve(Sigma)))/2
                 -kappa0/2*(mu-mu0)%*%crossprod(solve(Sigma), (mu-mu0)))
         }, mu=mu, Sigma=Sigma)
-
+    }else{
+      res <- mapply(function(mu, Sigma){
+        -(nu0+p+2)/2*log(det(Sigma))
+        -sum(diag(lambda0%*%solve(Sigma)))/2
+        -kappa0/2*(mu-mu0)%*%crossprod(solve(Sigma), (mu-mu0))
+      }, mu=mu, Sigma=Sigma)
+    }
     
     return(res)
 }
\ No newline at end of file
